==> org-lsst-sal-camera-2.6.4-sources.jar: org/lsst/sal/camera/event/Utiltrunk_VPCFan_PicConfigurationEvent.java <==
package org.lsst.sal.camera.event;

import org.lsst.sal.camera.CameraEvent;

public class Utiltrunk_VPCFan_PicConfigurationEvent extends CameraEvent {
  private final String version;

  private final double awGain;

  private final double baseDuty;

  private final double gain;

  private final double maxDutyCycle;

  private final double maxInput;

  private final int maxRpm;

  private final double minDutyCycle;

  private final double minInput;

  private final int minRpm;

  private final double offDutyCycle;

  private final double smoothTime;

  private final double timeConst;

  private final double tolerance;

  public Utiltrunk_VPCFan_PicConfigurationEvent(String version, double awGain, double baseDuty,
      double gain, double maxDutyCycle, double maxInput, int maxRpm, double minDutyCycle,
      double minInput, int minRpm, double offDutyCycle, double smoothTime, double timeConst,
      double tolerance) {
    this.version = version;
    this.awGain = awGain;
    this.baseDuty = baseDuty;
    this.gain = gain;
    this.maxDutyCycle = maxDutyCycle;
    this.maxInput = maxInput;
    this.maxRpm = maxRpm;
    this.minDutyCycle = minDutyCycle;
    this.minInput = minInput;
    this.minRpm = minRpm;
    this.offDutyCycle = offDutyCycle;
    this.smoothTime = smoothTime;
    this.timeConst = timeConst;
    this.tolerance = tolerance;
  }

  public String getVersion() {
    return version;
  }

  public double getAwGain() {
    return awGain;
  }

  public double getBaseDuty() {
    return baseDuty;
  }

  public double getGain() {
    return gain;
  }

  public double getMaxDutyCycle() {
    return maxDutyCycle;
  }

  public double getMaxInput() {
    return maxInput;
  }

  public int getMaxRpm() {
    return maxRpm;
  }

  public double getMinDutyCycle() {
    return minDutyCycle;
  }

  public double getMinInput() {
    return minInput;
  }

  public int getMinRpm() {
    return minRpm;
  }

  public double getOffDutyCycle() {
    return offDutyCycle;
  }

  public double getSmoothTime() {
    return smoothTime;
  }

  public double getTimeConst() {
    return timeConst;
  }

  public double getTolerance() {
    return tolerance;
  }

  @Override
  public String toString() {
    return "Utiltrunk_VPCFan_PicConfigurationEvent{" + "version=" + version +", awGain=" + awGain +
        ", baseDuty=" + baseDuty +", gain=" + gain +", maxDutyCycle=" + maxDutyCycle +
        ", maxInput=" + maxInput +", maxRpm=" + maxRpm +", minDutyCycle=" + minDutyCycle +
        ", minInput=" + minInput +", minRpm=" + minRpm +", offDutyCycle=" + offDutyCycle +
        ", smoothTime=" + smoothTime +", timeConst=" + timeConst +", tolerance=" + tolerance +"}";
  }

  public static Builder builder() {
    return new Builder();
  }

  public static class Builder {
    private String version;

    private double awGain;

    private double baseDuty;

    private double gain;

    private double maxDutyCycle;

    private double maxInput;

    private int maxRpm;

    private double minDutyCycle;

    private double minInput;

    private int minRpm;

    private double offDutyCycle;

    private double smoothTime;

    private double timeConst;

    private double tolerance;

    private Builder() {
    }

    public Builder version(String version) {
      this.version = version;
      return this;
    }

    public Builder awGain(double awGain) {
      this.awGain = awGain;
      return this;
    }

    public Builder baseDuty(double baseDuty) {
      this.baseDuty = baseDuty;
      return this;
    }

    public Builder gain(double gain) {
      this.gain = gain;
      return this;
    }

    public Builder maxDutyCycle(double maxDutyCycle) {
      this.maxDutyCycle = maxDutyCycle;
      return this;
    }

    public Builder maxInput(double maxInput) {
      this.maxInput = maxInput;
      return this;
    }

    public Builder maxRpm(int maxRpm) {
      this.maxRpm = maxRpm;
      return this;
    }

    public Builder minDutyCycle(double minDutyCycle) {
      this.minDutyCycle = minDutyCycle;
      return this;
    }

    public Builder minInput(double minInput) {
      this.minInput = minInput;
      return this;
    }

    public Builder minRpm(int minRpm) {
      this.minRpm = minRpm;
      return this;
    }

    public Builder offDutyCycle(double offDutyCycle) {
      this.offDutyCycle = offDutyCycle;
      return this;
    }

    public Builder smoothTime(double smoothTime) {
      this.smoothTime = smoothTime;
      return this;
    }

    public Builder timeConst(double timeConst) {
      this.timeConst = timeConst;
      return this;
    }

    public Builder tolerance(double tolerance) {
      this.tolerance = tolerance;
      return this;
    }

    public Utiltrunk_VPCFan_PicConfigurationEvent build() {
      return new Utiltrunk_VPCFan_PicConfigurationEvent(version, awGain, baseDuty, gain, maxDutyCycle, maxInput, maxRpm, minDutyCycle, minInput, minRpm, offDutyCycle, smoothTime, timeConst, tolerance);
    }
  }
}

==> org-lsst-sal-camera-3.0.1-sources.jar: org/lsst/sal/camera/event/Utiltrunk_VPCFan_PicConfigurationEvent.java <==
package org.lsst.sal.camera.event;

import org.lsst.sal.camera.CameraEvent;

public class Utiltrunk_VPCFan_PicConfigurationEvent extends CameraEvent {
  private final String version;

  private final double awGain;

  private final double baseDuty;

  private final double gain;

  private final double maxDutyCycle;

  private final double maxInput;

  private final int maxRpm;

  private final double minDutyCycle;

  private final double minInput;

  private final int minRpm;

  private final double offDutyCycle;

  private final int settleTime;

  private final double smoothTime;

  private final double timeConst;

  private final double tolerance;

  public Utiltrunk_VPCFan_PicConfigurationEvent(String version, double awGain, double baseDuty,
      double gain, double maxDutyCycle, double maxInput, int maxRpm, double minDutyCycle,
      double minInput, int minRpm, double offDutyCycle, int settleTime, double smoothTime,
      double timeConst, double tolerance) {
    this.version = version;
    this.awGain = awGain;
    this.baseDuty = baseDuty;
    this.gain = gain;
    this.maxDutyCycle = maxDutyCycle;
    this.maxInput = maxInput;
    this.maxRpm = maxRpm;
    this.minDutyCycle = minDutyCycle;
    this.minInput = minInput;
    this.minRpm = minRpm;
    this.offDutyCycle = offDutyCycle;
    this.settleTime = settleTime;
    this.smoothTime = smoothTime;
    this.timeConst = timeConst;
    this.tolerance = tolerance;
  }

  public String getVersion() {
    return version;
  }

  public double getAwGain() {
    return awGain;
  }

  public double getBaseDuty() {
    return baseDuty;
  }

  public double getGain() {
    return gain;
  }

  public double getMaxDutyCycle() {
    return maxDutyCycle;
  }

  public double getMaxInput() {
    return maxInput;
  }

  public int getMaxRpm() {
    return maxRpm;
  }

  public double getMinDutyCycle() {
    return minDutyCycle;
  }

  public double getMinInput() {
    return minInput;
  }

  public int getMinRpm() {
    return minRpm;
  }

  public double getOffDutyCycle() {
    return offDutyCycle;
  }

  public int getSettleTime() {
    return settleTime;
  }

  public double getSmoothTime() {
    return smoothTime;
  }

  public double getTimeConst() {
    return timeConst;
  }

  public double getTolerance() {
    return tolerance;
  }

  @Override
  public String toString() {
    return "Utiltrunk_VPCFan_PicConfigurationEvent{" + "version=" + version +", awGain=" + awGain +
        ", baseDuty=" + baseDuty +", gain=" + gain +", maxDutyCycle=" + maxDutyCycle +
        ", maxInput=" + maxInput +", maxRpm=" + maxRpm +", minDutyCycle=" + minDutyCycle +
        ", minInput=" + minInput +", minRpm=" + minRpm +", offDutyCycle=" + offDutyCycle +
        ", settleTime=" + settleTime +", smoothTime=" + smoothTime +", timeConst=" + timeConst +
        ", tolerance=" + tolerance +"}";
  }

  public static Builder builder() {
    return new Builder();
  }

  public static class Builder {
    private String version;

    private double awGain;

    private double baseDuty;

    private double gain;

    private double maxDutyCycle;

    private double maxInput;

    private int maxRpm;

    private double minDutyCycle;

    private double minInput;

    private int minRpm;

    private double offDutyCycle;

    private int settleTime;

    private double smoothTime;

    private double timeConst;

    private double tolerance;

    private Builder() {
    }

    public Builder version(String version) {
      this.version = version;
      return this;
    }

    public Builder awGain(double awGain) {
      this.awGain = awGain;
      return this;
    }

    public Builder baseDuty(double baseDuty) {
      this.baseDuty = baseDuty;
      return this;
    }

    public Builder gain(double gain) {
      this.gain = gain;
      return this;
    }

    public Builder maxDutyCycle(double maxDutyCycle) {
      this.maxDutyCycle = maxDutyCycle;
      return this;
    }

    public Builder maxInput(double maxInput) {
      this.maxInput = maxInput;
      return this;
    }

    public Builder maxRpm(int maxRpm) {
      this.maxRpm = maxRpm;
      return this;
    }

    public Builder minDutyCycle(double minDutyCycle) {
      this.minDutyCycle = minDutyCycle;
      return this;
    }

    public Builder minInput(double minInput) {
      this.minInput = minInput;
      return this;
    }

    public Builder minRpm(int minRpm) {
      this.minRpm = minRpm;
      return this;
    }

    public Builder offDutyCycle(double offDutyCycle) {
      this.offDutyCycle = offDutyCycle;
      return this;
    }

    public Builder settleTime(int settleTime) {
      this.settleTime = settleTime;
      return this;
    }

    public Builder smoothTime(double smoothTime) {
      this.smoothTime = smoothTime;
      return this;
    }

    public Builder timeConst(double timeConst) {
      this.timeConst = timeConst;
      return this;
    }

    public Builder tolerance(double tolerance) {
      this.tolerance = tolerance;
      return this;
    }

    public Utiltrunk_VPCFan_PicConfigurationEvent build() {
      return new Utiltrunk_VPCFan_PicConfigurationEvent(version, awGain, baseDuty, gain, maxDutyCycle, maxInput, maxRpm, minDutyCycle, minInput, minRpm, offDutyCycle, settleTime, smoothTime, timeConst, tolerance);
    }
  }
}
